# Babel Configurations
Standard configurations for [Babel](https://babeljs.io/).

**Why?** &mdash; We use Babel to support latest JavaScript specifications in our projects, and to allow for some fancy features in our code. The standard Babel configurations help to ensure that selected code patterns are supported in all of our apps.

Several Babel configurations are provided by this package:

[**config/babel/node-ssr.json**](#node-ssr) &mdash; Server-side configuration with support of server-side rendering;

To use any of these configurations in your code use `extend` Babel option in your `.babelrc` file, or whenever you need it, e.g.
```json
{
  "extend": "topcoder-react-utils/config/babel/node-ssr.json"
}
```
This way you can also easily tune some of Babel options in the way specific to your project; however if you feel that an option change you need is necessary for any generic react-based project, consider to submit an update to the configuration provided by `topcoder-react-utils`.

### Configuration Details

- <a name="node-ssr">**`config/babel/node-ssr.json`**</a> &mdash; Server-side configuration with support of server-side rendering.

  *Presets:* [env](https://www.npmjs.com/package/babel-preset-env), [react](https://www.npmjs.com/package/babel-preset-react), [stage-2](https://www.npmjs.com/package/babel-preset-stage-2)

  Converts imported CSS and SCSS modules into hashes where keys are class names and values are generated CSS class names (using [`css-modules-transform`](https://www.npmjs.com/package/babel-plugin-css-modules-transform) plugin).

  Implements compile-time CSS modules for SCSS files (using [`react-css-modules`](https://www.npmjs.com/package/babel-plugin-react-css-modules) plugin): class names from the imported SCSS files are transformed into (i) `.path-to-the-stylsheet___original-class-name` in development and test Babel environments, for the ease of debugging, (ii) `.6-symbols-hash` in production Babel environment, for smaller size of resulting JS bundles.

  Embeds imported SVG files into complied JSX code (using [`inline-react-svg`](https://www.npmjs.com/package/babel-plugin-inline-react-svg) plugin).

  Converts imported GIF, JPEG, JPG, and PNG assets into URL strings like `/images/hash-of-the-asset-file.original-file-extension`, where `/images/` is a fixed path prefix. This is done using [`tranform-assets`](https://www.npmjs.com/package/babel-plugin-transform-assets) plugin.

  Supports dynamic `import(..)` statement (using [`dynamic-import-node`](https://www.npmjs.com/package/babel-plugin-dynamic-import-node) plugin), and sets up [`transform-runtime`](https://www.npmjs.com/package/babel-plugin-transform-runtime).

  Sets up the following paths as the roots for resolution of relative imports: `./src/shared`, `./src` (using [module-resolver](https://www.npmjs.com/package/babel-plugin-module-resolver) plugin).
